@@ -5,9 +5,7 @@ from datetime import (
         )
 import tempfile
 
-import formencode as fe
 from formencode import validators as fev
-
 from ming.orm import session
 from pylons import tmpl_context as c
 from pylons import app_globals as g
@@ -25,11 +23,13 @@ from tg.decorators import (
 
 from allura.controllers import BaseController
 from allura.lib.decorators import require_post, task
+from allura.lib import helpers as h
 from allura.model import ApiTicket
 
 from forgeimporters.base import (
         ToolImporter,
         ToolImportForm,
+        ImportErrorHandler,
         )
 
 from forgewiki.scripts.wiki_from_trac.extractors import WikiExporter
@@ -40,7 +40,9 @@ from forgewiki.wiki_main import ForgeWikiApp
 
 @task(notifications_disabled=True)
 def import_tool(**kw):
-    TracWikiImporter().import_tool(c.project, c.user, **kw)
+    importer = TracWikiImporter()
+    with ImportErrorHandler(importer, kw.get('trac_url')):
+        importer.import_tool(c.project, c.user, **kw)
 
 
 class TracWikiImportForm(ToolImportForm):
@@ -80,7 +82,7 @@ class TracWikiImporter(ToolImporter):
     target_app = ForgeWikiApp
     source = 'Trac'
     controller = TracWikiImportController
-    tool_label = 'Trac Wiki Importer'
+    tool_label = 'Wiki'
     tool_description = 'Import your wiki from Trac.  Note: wiki content is imported, but not revision history or attachments.'
 
     def import_tool(self, project, user, project_name=None, mount_point=None,
@@ -96,23 +98,27 @@ class TracWikiImporter(ToolImporter):
                 mount_label=mount_label or 'Wiki',
                 )
         session(app.config).flush(app.config)
-        api_ticket = ApiTicket(user_id=user._id,
-                capabilities={"import": ["Projects", project.shortname]},
-                expires=datetime.utcnow() + timedelta(minutes=60))
-        session(api_ticket).flush(api_ticket)
-        options = argparse.Namespace()
-        options.api_key = api_ticket.api_key
-        options.secret_key = api_ticket.secret_key
-        options.project = project.shortname
-        options.wiki = mount_point
-        options.base_url = config['base_url']
-        options.verbose = False
-        options.converter = 'html2text'
-        options.import_opts = []
-        options.user_map_file = None
-        with tempfile.NamedTemporaryFile() as f:
-            WikiExporter(trac_url, options).export(f)
-            f.flush()
-            load_data(f.name, WikiFromTrac.parser(), options)
-        g.post_event('project_updated')
-        return app
+        try:
+            api_ticket = ApiTicket(user_id=user._id,
+                    capabilities={"import": ["Projects", project.shortname]},
+                    expires=datetime.utcnow() + timedelta(minutes=60))
+            session(api_ticket).flush(api_ticket)
+            options = argparse.Namespace()
+            options.api_key = api_ticket.api_key
+            options.secret_key = api_ticket.secret_key
+            options.project = project.shortname
+            options.wiki = mount_point
+            options.base_url = config['base_url']
+            options.verbose = False
+            options.converter = 'html2text'
+            options.import_opts = []
+            options.user_map_file = None
+            with tempfile.NamedTemporaryFile() as f:
+                WikiExporter(trac_url, options).export(f)
+                f.flush()
+                load_data(f.name, WikiFromTrac.parser(), options)
+            g.post_event('project_updated')
+            return app
+        except Exception as e:
+            h.make_app_admin_only(app)
+            raise
