@@ -10,7 +10,7 @@ from tracwikiimporter.importer import (
     )
 
 
-class TestWikiTicketImporter(TestCase):
+class TestTracWikiImporter(TestCase):
     @patch('tracwikiimporter.importer.session')
     @patch('tracwikiimporter.importer.tempfile.NamedTemporaryFile')
     @patch('tracwikiimporter.importer.g')
@@ -51,6 +51,23 @@ class TestWikiTicketImporter(TestCase):
                 WikiFromTrac.parser.return_value, Namespace.return_value)
         g.post_event.assert_called_once_with('project_updated')
 
+    @patch('tracwikiimporter.importer.session')
+    @patch('tracwikiimporter.importer.ApiTicket')
+    @patch('tracwikiimporter.importer.h')
+    def test_import_tool_failure(self, h, ApiTicket, session):
+        ApiTicket.side_effect = ValueError
+        importer = TracWikiImporter()
+        app = Mock(name='ForgeWikiApp')
+        project = Mock(name='Project', shortname='myproject')
+        project.install_app.return_value = app
+        user = Mock(name='User', _id='id')
+        self.assertRaises(ValueError, importer.import_tool,
+                project, user,
+                mount_point='pages',
+                mount_label='Pages',
+                trac_url='http://example.com/trac/url')
+        h.make_app_admin_only.assert_called_once_with(app)
+
 
 class TestTracWikiImportController(TestController, TestCase):
     def setUp(self):
